@@ -7,7 +7,7 @@ import pkg_resources
 from django.db import transaction
 from django.db.models import Count
 from django.template import Context, Template
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 import pytz
 from web_fragments.fragment import Fragment
 from webob.response import Response
@@ -52,7 +52,7 @@ def staff_only(handler_method):
     Wrapper that ensures a handler method is enabled for staff users only
     """
     @wraps(handler_method)
-    def wrapper(aside_instance, *args, **kwargs):  # pylint: disable=missing-docstring
+    def wrapper(aside_instance, *args, **kwargs):
         if not aside_instance.is_staff():
             return Response(
                 status=403,
